ScenarioStepSerialized

Enum ScenarioStepSerialized 

pub enum ScenarioStepSerialized {
Show 20 variants Comment { comment: String, }, InstallPlugin { context_policy: Option<ContextMode>, emit_responses: Option<bool>, nanoseconds_budget: Option<u64>, }, SetNanosecondsBudget { nanoseconds_budget: Option<u64>, }, FinalizeApp, SetupHandler { schedule: ScenarioSchedule, label: ScenarioLabel, }, LoadScriptAs { path: PathBuf, as_name: String, }, WaitForScriptAssetLoaded { name: String, }, SpawnEntityWithScript { name: String, script: String, }, AttachStaticScript { script: String, }, DetachStaticScript { script: String, }, DropScriptAsset { script: String, }, DespawnEntity { entity: String, }, EmitScriptCallbackEvent { label: ScenarioLabel, recipients: ScenarioRecipients, language: Option<ScenarioLanguage>, emit_response: bool, string_value: Option<String>, }, RunUpdateOnce, AssertCallbackSuccess { label: ScenarioLabel, attachment: ScenarioAttachment, expect_string_value: Option<String>, language: Option<ScenarioLanguage>, }, AssertNoCallbackResponsesEmitted, AssertContextState { attachment: ScenarioAttachment, state: ScenarioContextState, }, AssertContextResidents { script: ScenarioAttachment, residents_num: usize, }, ReloadScriptFrom { script: String, path: PathBuf, }, SetCurrentLanguage { language: ScenarioLanguage, },
}
Describes the available scenario steps

Variants



Comment

arbitrary comment

Fields

comment: String

a comment



InstallPlugin

Installs the scripting plugin with the given settings and intializes the app

Fields

context_policy: Option<ContextMode>

the context policy to use in the scenario

emit_responses: Option<bool>

sets the emit_responses flag for core callbacks

nanoseconds_budget: Option<u64>

the amount of nanoseconds to set the loading budget to



SetNanosecondsBudget

Sets the pipeline processing budget

Fields

nanoseconds_budget: Option<u64>

the amount of nanoseconds to set the loading budget to



FinalizeApp

Called after the app config is set up, but before we run anything



SetupHandler

Sets up a handler for the given schedule and label. You can onle use one of the following callbacks:

  • on_test
  • on_test_post_update
  • on_test_last
  • callback_a
  • callback_b
  • callback_c

and main bevy schedule labels.

Fields

schedule: ScenarioSchedule

the schedule in which to place this handler

label: ScenarioLabel

the callback label to setup this handler for



LoadScriptAs

Loads a script from the given path and assigns it a name, this handle can be used later when loaded.

Fields

path: PathBuf

the path to load the script from

as_name: String

the name to give this script for future reference



WaitForScriptAssetLoaded

Waits until the script with the given name is loaded.

Fields

name: String

the name of the script for which to wait



SpawnEntityWithScript

Spawns an entity with the given name and attaches the given script to it.

Fields

name: String

the name to give this entity for future reference

script: String

the script to spawn on the entity



AttachStaticScript

Attaches a static script

Fields

script: String

the script to be attached



DetachStaticScript

Detaches a static script

Fields

script: String

the script to be detached



DropScriptAsset

Drops the script asset from the scenario context.

Fields

script: String

the script to drop the asset for



DespawnEntity

Despawns the entity with the given name.

Fields

entity: String

the entity to despawn



EmitScriptCallbackEvent

Emits a ScriptCallbackEvent

Fields

label: ScenarioLabel

the label to fire the callback for

recipients: ScenarioRecipients

the recipients to set on the callback event

language: Option<ScenarioLanguage>

the language to set on the callback event

emit_response: bool

sets the emit_response flag on the callback event

string_value: Option<String>

the string value to send as payload



RunUpdateOnce

Run the app update loop once



AssertCallbackSuccess

Asserts that a callback response was triggered for the given script attachment

Fields

label: ScenarioLabel

the label for which to query

attachment: ScenarioAttachment

the attachment to query

expect_string_value: Option<String>

the string value to expect returned from the callback

language: Option<ScenarioLanguage>

the language to query



AssertNoCallbackResponsesEmitted

Assert that no callbacks were emitted this frame



AssertContextState

Asserts that the context for the given attachment is in a certain state

Fields

attachment: ScenarioAttachment

the attachment to query

state: ScenarioContextState

the context state to assert



AssertContextResidents

Assert that the context for the given attachment has a certain amount of residents

Fields

script: ScenarioAttachment

the attachment to query

residents_num: usize

number of residents to expect



ReloadScriptFrom

Modifies the existing script asset by reloading it from the given path.

Fields

script: String

the script to reload

path: PathBuf

the path to reload the new content from



SetCurrentLanguage

Sets the current script language context to be used untll this is changed

Fields

language: ScenarioLanguage

the language

Implementations

Source

impl ScenarioStepSerialized

pub fn to_json(&self) -> Result<String, Error>

serialize a single scenario step to a json representation

pub fn from_json(json: &str) -> Result<Self, Error>

deserialize a single scenario step from a json representation

pub fn to_flat_string(&self) -> Result<String, Error>

converts to json object then converts to a format like: StepName key=“value”, key2=value2

pub fn from_flat_string(flat_string: &str) -> Result<Self, Error>

deserialize a single scenario step from a flattened text representation